@@ -1,6 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
-# Copyright 2011 OpenStack LLC.
+# Copyright 2011 OpenStack Foundation
 # Copyright 2011, Piston Cloud Computing, Inc.
 # Copyright 2013 Rackspace Hosting
 # All Rights Reserved.
@@ -18,7 +16,7 @@
 # limitations under the License.
 
 
-from troveclient.openstack.common.apiclient import exceptions
+from troveclient.apiclient import exceptions
 
 
 class ServiceCatalog(object):
