@@ -193,6 +193,28 @@ class FakeHTTPClient(base_client.HTTPClient):
         r = {'instance': self.get_instances()[2]['instances'][0]}
         return (200, {}, r)
 
+    def get_instance_create(self, **kw):
+        return (200, {}, {"instance": {
+                "status": "BUILD",
+                "updated": "2017-12-22T20:02:32",
+                "name": "test",
+                "created": "2017-12-22T20:02:32",
+                "networks": {
+                    "name": "test-net",
+                    "id": "net-id"
+                },
+                "id": "2468",
+                "volume": {
+                    "size": 1
+                },
+                "flavor": {
+                    "id": "310"
+                },
+                "datastore": {
+                    "version": "5.6",
+                    "type": "mysql"
+                }}})
+
     def post_instances(self, body, **kw):
         assert_has_keys(
             body['instance'],
@@ -325,8 +347,42 @@ class FakeHTTPClient(base_client.HTTPClient):
                 "id": "cls-1234"}]})
 
     def get_clusters_cls_1234(self, **kw):
-        r = {'cluster': self.get_clusters()[2]['clusters'][0]}
-        return (200, {}, r)
+        # NOTE(zhaochao): getting a cluster will load instances
+        # informations while getting the list of clusters won't,
+        # so we cannot just reuse the reponse of getting clusters
+        # for getting a cluster.
+        # The following response body is almost identical to the
+        # result of get_clusters, except the additional 'status'
+        # and 'volume' items, so all existing unitests accessing
+        # this piece of fake response will continue to work
+        # without any modification.
+        return (200, {}, {'cluster': {
+            "instances": [
+                {
+                    "type": "member",
+                    "id": "member-1",
+                    "ip": ["10.0.0.3"],
+                    "flavor": {"id": "02"},
+                    "name": "test-clstr-member-1",
+                    "status": "ACTIVE",
+                    "volume": {"size": 2}
+                },
+                {
+                    "type": "member",
+                    "id": "member-2",
+                    "ip": ["10.0.0.4"],
+                    "flavor": {"id": "2"},
+                    "name": "test-clstr-member-2",
+                    "status": "ACTIVE",
+                    "volume": {"size": 2}
+                }],
+            "updated": "2015-05-02T11:06:19",
+            "task": {"description": "No tasks for the cluster.", "id": 1,
+                     "name": "NONE"},
+            "name": "test-clstr",
+            "created": "2015-05-02T10:37:04",
+            "datastore": {"version": "7.1", "type": "vertica"},
+            "id": "cls-1234"}})
 
     def delete_instances_1234(self, **kw):
         return (202, {}, None)
@@ -703,3 +759,27 @@ class FakeHTTPClient(base_client.HTTPClient):
                 "to_port": 3306,
                 "security_group_id": "2",
                 "cidr": "15.0.0.0/24", "id": 3}]})
+
+    def get_quotas(self, **kw):
+        return (200, {}, {"quotas": [
+            {
+                "reserved": 1,
+                "resource": "instances",
+                "limit": 10,
+                "in_use": 2
+            },
+            {
+                "reserved": 3,
+                "resource": "backups",
+                "limit": 50,
+                "in_use": 4
+            },
+            {
+                "reserved": 5,
+                "resource": "volumes",
+                "limit": 40,
+                "in_use": 6
+            }]})
+
+    def update_instances_quota(self, **kw):
+        return (200, {}, {"quotas": {"instances": 51}})
