@@ -157,7 +157,7 @@ def print_list(objs, fields, formatters={}, order_by=None, obj_is_dict=False,
     for field in fields:
         if field not in labels:
             # No underscores (use spaces instead) and uppercase any ID's
-            label = field.replace("_", " ").replace("id", "ID")
+            label = field.replace("_", " ").replace(" id", " ID")
             # Uppercase anything else that's less than 3 chars
             if len(label) < 3:
                 label = label.upper()
@@ -181,7 +181,10 @@ def print_list(objs, fields, formatters={}, order_by=None, obj_is_dict=False,
                 data = obj.get(field, '')
             else:
                 data = getattr(obj, field, '')
-            row.append(str(data))
+            if isinstance(data, six.string_types):
+                row.append(data.encode('utf-8'))
+            else:
+                row.append(str(data))
             # set the alignment to right-aligned if it's a numeric
             if set_align and hasattr(data, '__int__'):
                 align[labels[field]] = 'r'
@@ -211,10 +214,12 @@ def find_resource(manager, name_or_id):
     """Helper for the _find_* methods."""
     # first try to get entity as integer id
 
-    # if the 'id' starts with '0' don't treat it as an int
-    if isinstance(name_or_id, int) or (
-            name_or_id.isdigit() and not name_or_id.startswith('0')):
-        name_or_id = int(name_or_id)
+    # When the 'name_or_id' is int, covert it to string.
+    # Reason is that manager cannot find instance when name_or_id
+    # is integer and instance name is digital.
+    # Related to bug/1740015.
+    if isinstance(name_or_id, int):
+        name_or_id = six.text_type(name_or_id)
     elif sys.version_info <= (3, 0):
         name_or_id = encodeutils.safe_decode(name_or_id)
 
@@ -324,3 +329,26 @@ def decode_data(data):
 
     # py27 & py34 seem to understand bytearray the same
     return bytearray([item for item in base64.b64decode(data)])
+
+
+def do_action_with_msg(action, success_msg):
+    """Helper to run an action with return message."""
+
+    action
+    print(success_msg)
+
+
+def do_action_on_many(action, resources, success_msg, error_msg):
+    """Helper to run an action on many resources."""
+    failure_flag = False
+
+    for resource in resources:
+        try:
+            action(resource)
+            print(success_msg % resource)
+        except Exception as e:
+            failure_flag = True
+            print(encodeutils.safe_encode(six.text_type(e)))
+
+    if failure_flag:
+        raise exceptions.CommandError(error_msg)
