@@ -71,8 +71,8 @@ class Backups(base.ManagerWithFind):
         return self._paginated("/backups", "backups", limit, marker,
                                query_strings)
 
-    def create(self, name, instance, description=None, parent_id=None,
-               backup=None, incremental=False):
+    def create(self, name, instance, description=None,
+               parent_id=None, incremental=False):
         """Create a new backup from the given instance.
 
         :param name: name for backup.
@@ -80,7 +80,7 @@ class Backups(base.ManagerWithFind):
         :param description: (optional).
         :param parent_id: base for incremental backup (optional).
         :param incremental: flag to indicate incremental backup based on
-        last backup
+                            last backup
         :returns: :class:`Backups`
         """
         body = {
@@ -92,8 +92,6 @@ class Backups(base.ManagerWithFind):
 
         if instance:
             body['backup']['instance'] = base.getid(instance)
-        if backup:
-            body["backup"]['backup'] = backup
         if description:
             body['backup']['description'] = description
         if parent_id:
@@ -119,9 +117,9 @@ class Backups(base.ManagerWithFind):
             tenant_name = self.api.client.auth._project_name
         else:
             auth_url = self.api.client.auth_url
-            user = self.api.client.username
+            user = self.api.client.user
             key = self.api.client.password
-            tenant_name = self.api.client.tenant
+            tenant_name = self.api.client.projectid
 
         return mistral_client(auth_url=auth_url, username=user, api_key=key,
                               project_name=tenant_name)
