@@ -16,12 +16,10 @@
 #    under the License.
 
 import os
-import warnings
 
 from troveclient import base
 from troveclient import common
 from troveclient import exceptions
-from troveclient.i18n import _LW
 from troveclient import utils
 from troveclient.v1 import modules as core_modules
 
@@ -41,6 +39,11 @@ class Instance(base.Resource):
         """Delete the instance."""
         self.manager.delete(self)
 
+    def force_delete(self):
+        """Force delete the instance"""
+        self.manager.reset_status(self)
+        self.manager.delete(self)
+
     def restart(self):
         """Restart the database instance."""
         self.manager.restart(self.id)
@@ -67,11 +70,14 @@ class Instances(base.ManagerWithFind):
             user = self.api.client.auth._username
             key = self.api.client.auth._password
             tenant_name = self.api.client.auth._project_name
+            auth_version = "3.0"
         else:
             auth_url = self.api.client.auth_url
             user = self.api.client.username
             key = self.api.client.password
             tenant_name = self.api.client.tenant
+            auth_version = "2.0"
+
         # remove '/tokens' from the end of auth_url so it works for swift
         token_str = "/tokens"
         if auth_url.endswith(token_str):
@@ -80,14 +86,14 @@ class Instances(base.ManagerWithFind):
         os_options = {'tenant_name': tenant_name, 'region_name': region_name}
 
         return swift_client.Connection(
-            auth_url, user, key, auth_version="2.0", os_options=os_options)
+            auth_url, user, key, auth_version=auth_version,
+            os_options=os_options)
 
-    # TODO(mriedem): Remove slave_of after liberty-eol for Trove.
     def create(self, name, flavor_id, volume=None, databases=None, users=None,
                restorePoint=None, availability_zone=None, datastore=None,
                datastore_version=None, nics=None, configuration=None,
-               replica_of=None, slave_of=None, replica_count=None,
-               modules=None, locality=None):
+               replica_of=None, replica_count=None, modules=None,
+               locality=None, region_name=None):
         """Create (boot) a new instance."""
 
         body = {"instance": {
@@ -115,20 +121,16 @@ class Instances(base.ManagerWithFind):
             body["instance"]["nics"] = nics
         if configuration:
             body["instance"]["configuration"] = base.getid(configuration)
-        if replica_of or slave_of:
-            if slave_of:
-                warnings.warn(_LW("The 'slave_of' argument is deprecated in "
-                                  "favor of 'replica_of' and will be removed "
-                                  "after the Trove liberty series is end of "
-                                  "life."),
-                              category=DeprecationWarning)
-            body["instance"]["replica_of"] = base.getid(replica_of) or slave_of
+        if replica_of:
+            body["instance"]["replica_of"] = base.getid(replica_of)
         if replica_count:
             body["instance"]["replica_count"] = replica_count
         if modules:
             body["instance"]["modules"] = self._get_module_list(modules)
         if locality:
             body["instance"]["locality"] = locality
+        if region_name:
+            body["instance"]["region_name"] = region_name
 
         return self._create("/instances", body, "instance")
 
@@ -159,14 +161,24 @@ class Instances(base.ManagerWithFind):
         if name is not None:
             body["instance"]["name"] = name
         if detach_replica_source:
-            # NOTE(mriedem): We don't send slave_of since it was removed from
-            # the trove API in mitaka.
             body["instance"]["replica_of"] = None
 
         url = "/instances/%s" % base.getid(instance)
         resp, body = self.api.client.patch(url, body=body)
         common.check_for_exceptions(resp, body, url)
 
+    def upgrade(self, instance, datastore_version):
+        """Upgrades an instance with a new datastore version."""
+        body = {
+            "instance": {
+                "datastore_version": datastore_version
+            }
+        }
+
+        url = "/instances/%s" % base.getid(instance)
+        resp, body = self.api.client.patch(url, body=body)
+        common.check_for_exceptions(resp, body, url)
+
     def list(self, limit=None, marker=None, include_clustered=False):
         """Get a list of all instances.
 
@@ -203,6 +215,22 @@ class Instances(base.ManagerWithFind):
         resp, body = self.api.client.delete(url)
         common.check_for_exceptions(resp, body, url)
 
+    def reset_status(self, instance):
+        """Reset the status of an instance.
+
+        :param instance: A reference to the instance
+        """
+        body = {'reset_status': {}}
+        self._action(instance, body)
+
+    def force_delete(self, instance):
+        """Force delete the specified instance.
+
+        :param instance: A reference to the instance to force delete
+        """
+        self.reset_status(instance)
+        self.delete(instance)
+
     def _action(self, instance, body):
         """Perform a server "action" -- reboot/rebuild/resize/etc."""
         url = "/instances/%s/action" % base.getid(instance)
@@ -226,7 +254,7 @@ class Instances(base.ManagerWithFind):
         """Restart the database instance.
 
         :param instance: The :class:`Instance` (or its ID) of the database
-        instance to restart.
+                         instance to restart.
         """
         body = {'restart': {}}
         self._action(instance, body)
@@ -243,7 +271,7 @@ class Instances(base.ManagerWithFind):
         """Promote a replica to be the new replica_source of its set
 
         :param instance: The :class:`Instance` (or its ID) of the database
-        instance to promote.
+                         instance to promote.
         """
         body = {'promote_to_replica_source': {}}
         self._action(instance, body)
@@ -252,7 +280,7 @@ class Instances(base.ManagerWithFind):
         """Eject a replica source from its set
 
         :param instance: The :class:`Instance` (or its ID) of the database
-        instance to eject.
+                         instance to eject.
         """
         body = {'eject_replica_source': {}}
         self._action(instance, body)
@@ -340,7 +368,7 @@ class Instances(base.ManagerWithFind):
         """Get a list of all guest logs.
 
         :param instance: The :class:`Instance` (or its ID) of the database
-        instance to get the log for.
+                         instance to get the log for.
         :rtype: list of :class:`DatastoreLog`.
         """
         url = '/instances/%s/log' % base.getid(instance)
@@ -370,7 +398,7 @@ class Instances(base.ManagerWithFind):
         """Perform action on guest log.
 
         :param instance: The :class:`Instance` (or its ID) of the database
-        instance to get the log for.
+                         instance to get the log for.
         :param log_name: The name of <log> to publish
         :param enable: Turn on <log>
         :param disable: Turn off <log>
@@ -409,7 +437,7 @@ class Instances(base.ManagerWithFind):
         """Return generator to yield the last <lines> lines of guest log.
 
         :param instance: The :class:`Instance` (or its ID) of the database
-        instance to get the log for.
+                         instance to get the log for.
         :param log_name: The name of <log> to publish
         :param publish: Publish updates before displaying log
         :param lines: Display last <lines> lines of log (0 for all lines)
@@ -464,7 +492,7 @@ class Instances(base.ManagerWithFind):
         """Saves a guest log to a file.
 
         :param instance: The :class:`Instance` (or its ID) of the database
-        instance to get the log for.
+                         instance to get the log for.
         :param log_name: The name of <log> to publish
         :param publish: Publish updates before displaying log
         :rtype: Filename to which log was saved
