@@ -103,6 +103,9 @@ def _print_instance(instance):
     if hasattr(instance, 'replicas'):
         replicas = [replica['id'] for replica in instance.replicas]
         info['replicas'] = ', '.join(replicas)
+    if hasattr(instance, 'networks'):
+        info['networks'] = instance.networks['name']
+        info['networks_id'] = instance.networks['id']
     if hasattr(instance, 'fault'):
         info.pop('fault', None)
         info['fault'] = instance.fault['message']
@@ -140,6 +143,12 @@ def _print_object(obj):
         obj._info['id'] = obj.id
         del(obj._info['str_id'])
 
+    # Get datastore type and version, where necessary
+    if hasattr(obj, 'datastore'):
+        if 'type' in obj.datastore:
+            obj._info['datastore'] = obj.datastore['type']
+            obj._info['datastore_version'] = obj.datastore['version']
+
     utils.print_dict(obj._info)
 
 
@@ -231,7 +240,8 @@ def do_flavor_list(cs, args):
 
     utils.print_list(_flavors, ['id', 'name', 'ram', 'vcpus', 'disk',
                                 'ephemeral'],
-                     labels={'ram': 'RAM', 'vcpus': 'vCPUs', 'disk': 'Disk'})
+                     labels={'ram': 'RAM', 'vcpus': 'vCPUs', 'disk': 'Disk'},
+                     order_by='ram')
 
 
 @utils.arg('flavor', metavar='<flavor>', type=str,
@@ -305,6 +315,8 @@ def _print_instances(instances, is_admin=False):
             setattr(instance, 'size', instance.volume['size'])
         else:
             setattr(instance, 'size', '-')
+        if not hasattr(instance, 'region'):
+            setattr(instance, 'region', '')
         if hasattr(instance, 'datastore'):
             if instance.datastore.get('version'):
                 setattr(instance, 'datastore_version',
@@ -399,13 +411,16 @@ def do_cluster_shrink(cs, args):
     cs.clusters.shrink(cluster, instances=instances)
 
 
-@utils.arg('instance', metavar='<instance>',
-           help=_('ID or name of the instance.'))
+@utils.arg('instance', metavar='<instance>', nargs='+',
+           help=_('ID or name of the instance(s).'))
 @utils.service_type('database')
 def do_delete(cs, args):
-    """Deletes an instance."""
-    instance = _find_instance(cs, args.instance)
-    cs.instances.delete(instance)
+    """Delete specified instance(s)."""
+    utils.do_action_on_many(
+        lambda s: cs.instances.delete(_find_instance(cs, s)),
+        args.instance,
+        _("Request to delete instance %s has been accepted."),
+        _("Unable to delete the specified instance(s)."))
 
 
 @utils.arg('instance', metavar='<instance>',
@@ -414,8 +429,10 @@ def do_delete(cs, args):
 def do_force_delete(cs, args):
     """Force delete an instance."""
     instance = _find_instance(cs, args.instance)
+    msg = _("Request to force delete instance %s "
+            "has been accepted.") % instance.id
     cs.instances.reset_status(instance)
-    cs.instances.delete(instance)
+    utils.do_action_with_msg(cs.instances.delete(instance), msg)
 
 
 @utils.arg('instance', metavar='<instance>',
@@ -430,13 +447,16 @@ def do_reset_status(cs, args):
     cs.instances.reset_status(instance=instance)
 
 
-@utils.arg('cluster', metavar='<cluster>',
-           help=_('ID or name of the cluster.'))
+@utils.arg('cluster', metavar='<cluster>', nargs='+',
+           help=_('ID or name of the cluster(s).'))
 @utils.service_type('database')
 def do_cluster_delete(cs, args):
-    """Deletes a cluster."""
-    cluster = _find_cluster(cs, args.cluster)
-    cs.clusters.delete(cluster)
+    """Delete specified cluster(s)."""
+    utils.do_action_on_many(
+        lambda s: cs.clusters.delete(_find_cluster(cs, s)),
+        args.cluster,
+        _("Request to delete cluster %s has been accepted."),
+        _("Unable to delete the specified cluster(s)."))
 
 
 @utils.arg('cluster', metavar='<cluster>',
@@ -445,8 +465,10 @@ def do_cluster_delete(cs, args):
 def do_cluster_force_delete(cs, args):
     """Force delete a cluster"""
     cluster = _find_cluster(cs, args.cluster)
+    msg = _("Request to force delete cluster %s "
+            "has been accepted.") % cluster.id
     cs.clusters.reset_status(cluster)
-    cs.clusters.delete(cluster)
+    utils.do_action_with_msg(cs.clusters.delete(cluster), msg)
 
 
 @utils.arg('cluster', metavar='<cluster>',
@@ -1048,30 +1070,6 @@ def do_backup_create(cs, args):
     _print_object(backup)
 
 
-@utils.arg('name', metavar='<name>', help=_('Name of the backup.'))
-@utils.arg('backup', metavar='<backup>',
-           help=_('Backup ID of the source backup.'),
-           default=None)
-@utils.arg('--region', metavar='<region>', default=None,
-           # help=_('Region where the source backup resides.'))
-           help=argparse.SUPPRESS)
-@utils.arg('--description', metavar='<description>',
-           default=None,
-           help=_('An optional description for the backup.'))
-@utils.service_type('database')
-def do_backup_copy(cs, args):
-    """Creates a backup from another backup."""
-    if args.backup:
-        backup_ref = {"id": args.backup,
-                      "region": args.region}
-    else:
-        backup_ref = None
-    backup = cs.backups.create(args.name, instance=None,
-                               description=args.description,
-                               parent_id=None, backup=backup_ref,)
-    _print_object(backup)
-
-
 @utils.arg('instance', metavar='<instance>',
            help=_('ID or name of the instance.'))
 @utils.arg('pattern', metavar='<pattern>',
@@ -1438,7 +1436,7 @@ def do_secgroup_list_rules(cs, args):
 
 
 @utils.arg('security_group_rule', metavar='<security_group_rule>',
-           help=_('Name of security group rule.'))
+           help=_('ID of security group rule.'))
 @utils.service_type('database')
 def do_secgroup_delete_rule(cs, args):
     """Deletes a security group rule."""
@@ -1603,6 +1601,11 @@ def do_configuration_parameter_show(cs, args):
         param = cs.configuration_parameters.get_parameter_by_version(
             args.datastore_version,
             args.parameter)
+    else:
+        raise exceptions.NoUniqueMatch(_('The datastore name or id is'
+                                         ' required to retrieve the'
+                                         ' parameter for the configuration'
+                                         ' group by name.'))
     _print_object(param)
 
 
